@@ -2,4 +2,5 @@ from eloquentarduino.ml import data
 from eloquentarduino.ml import plot
 from eloquentarduino.ml.data import Pipeline
 from eloquentarduino.ml.data import PipelineGridSearch
-from eloquentarduino.ml.Classifier import Classifier
+# @deprecated
+#from eloquentarduino.ml.Classifier import Classifier
